==> pmb8.0.1.0.zip: pmb/opac_css/cms/modules/common/selectors/cms_module_common_selector_global_var.class.php <==
<?php
// +-------------------------------------------------+
//  2002-2012 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: cms_module_common_selector_global_var.class.php,v 1.3 2017/07/12 15:15:01 tsamson Exp $

if (stristr($_SERVER['REQUEST_URI'], ".class.php")) die("no access");
//require_once($base_path."/cms/modules/common/selectors/cms_module_selector.class.php");
class cms_module_common_selector_global_var extends cms_module_common_selector{
	
	public function __construct($id=0){
		parent::__construct($id);
	}
	
	public function get_form(){
		$form = "
			<div class='row'>
				<div class='colonne3'>
					<label for=''>".$this->format_text($this->msg['cms_module_common_selector_global_var_label'])."</label>
				</div>
				<div class='colonne-suite'>
					<input type='text' name='".$this->get_form_value_name("global")."' value='".$this->addslashes($this->format_text($this->parameters))."'/>
				</div>
			</div>";
		$form.=parent::get_form();
		return $form;
	}
	
	public function save_form(){
		$this->parameters = $this->get_value_from_form("global");
		return parent ::save_form();
	}
	
	/*
	 * Retourne la valeur slectionn
	 */
	public function get_value(){
		if(!$this->value){
			$value = $this->parameters;
			global ${$value};
			if(isset(${$value})){
				$this->value = ${$value};
			}else{
				$this->value = false;
			}
		}
		return $this->value;
	}
	
	public function get_human_description_selector(){
		$description = $this->addslashes($this->format_text($this->parameters));
		return $description;
	}
}

==> pmb8.0.1.27.zip: pmb/opac_css/cms/modules/common/selectors/cms_module_common_selector_global_var.class.php <==
<?php
// +-------------------------------------------------+
//  2002-2012 PMB Services / www.sigb.net pmb@sigb.net et contributeurs (voir www.sigb.net)
// +-------------------------------------------------+
// $Id: cms_module_common_selector_global_var.class.php,v 1.3.18.1 2025/12/18 10:59:50 qvarin Exp $

if (stristr($_SERVER['REQUEST_URI'], ".class.php")) die("no access");
//require_once($base_path."/cms/modules/common/selectors/cms_module_selector.class.php");
class cms_module_common_selector_global_var extends cms_module_common_selector{

	public function __construct($id=0){
		parent::__construct($id);
	}

	public function get_form(){
		$form = "
			<div class='row'>
				<div class='colonne3'>
					<label for=''>".$this->format_text($this->msg['cms_module_common_selector_global_var_label'])."</label>
				</div>
				<div class='colonne-suite'>
					<input type='text' name='".$this->get_form_value_name("global")."' value='".static::addslashes($this->format_text($this->parameters))."'/>
				</div>
			</div>";
		$form.=parent::get_form();
		return $form;
	}

	public function save_form(){
		$this->parameters = $this->get_value_from_form("global");
		return parent ::save_form();
	}

	/*
	 * Retourne la valeur slectionn
	 */
	public function get_value(){
		if(!$this->value){
			$value = $this->parameters;
			global ${$value};
			if(isset(${$value})){
				$this->value = ${$value};
			}else{
				$this->value = false;
			}
		}
		return $this->value;
	}

	public function get_human_description_selector(){
		$description = static::addslashes($this->format_text($this->parameters));
		return $description;
	}
}
